1.0.0
-----

* Repackage to hatch/pyproject.toml

0.0.4
-----

* Add support for forced-mode on demand i2c
* Change altitude formula
* Allow manual temperature compensation for altitude
* Allow oversampling settings to be configured on `__init__`

0.0.3
-----

* Migrate to i2cdevice>=0.0.6 set/get API

0.0.2
-----

* Added `get_altitude` method
* Corrected pressure to hPa

0.0.1
-----

* Initial Release
